r'''
# netapp-fsxn-snapshot

> AWS CDK [L1 construct](https://docs.aws.amazon.com/cdk/latest/guide/constructs.html) and data structures for the [AWS CloudFormation Registry](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/registry.html) type `NetApp::FSxN::Snapshot` v1.1.0.

## Description

A snapshot creates a read-only copy of a volume or LUN at a specific time. It allows users to restore files or volumes if data is deleted, corrupted, or changed. Snapshots efficiently store only the changes made after the snapshot, making them ideal for data protection and recovery. Once activated, you need a preview key to consume this resource. Please reach out to Ng-fsx-cloudformation@netapp.com to get the key. To use this resource, you must first create the Link module.

## References

* [Source](https://github.com/NetApp/NetApp-CloudFormation-FSx-ONTAP-provider)

## Usage

In order to use this library, you will need to activate this AWS CloudFormation Registry type in your account. You can do this via the AWS Management Console or using the [AWS CLI](https://aws.amazon.com/cli/) using the following command:

```sh
aws cloudformation activate-type \
  --type-name NetApp::FSxN::Snapshot \
  --publisher-id a25d267c2b9b86b8d408fce3c7a4d94d34c90946 \
  --type RESOURCE \
  --execution-role-arn ROLE-ARN
```

Alternatively:

```sh
aws cloudformation activate-type \
  --public-type-arn arn:aws:cloudformation:us-east-1::type/resource/a25d267c2b9b86b8d408fce3c7a4d94d34c90946/NetApp-FSxN-Snapshot \
  --execution-role-arn ROLE-ARN
```

You can find more information about activating this type in the [AWS CloudFormation documentation](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/registry-public.html).

## Feedback

This library is auto-generated and published to all supported programming languages by the [cdklabs/cdk-cloudformation](https://github.com/cdklabs/cdk-cloudformation) project based on the API schema published for `NetApp::FSxN::Snapshot`.

* Issues related to this generated library should be [reported here](https://github.com/cdklabs/cdk-cloudformation/issues/new?title=Issue+with+%40cdk-cloudformation%2Fnetapp-fsxn-snapshot+v1.1.0).
* Issues related to `NetApp::FSxN::Snapshot` should be reported to the [publisher](https://github.com/NetApp/NetApp-CloudFormation-FSx-ONTAP-provider).

## License

Distributed under the Apache-2.0 License.
'''
from pkgutil import extend_path
__path__ = extend_path(__path__, __name__)

import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import typeguard
from importlib.metadata import version as _metadata_package_version
TYPEGUARD_MAJOR_VERSION = int(_metadata_package_version('typeguard').split('.')[0])

def check_type(argname: str, value: object, expected_type: typing.Any) -> typing.Any:
    if TYPEGUARD_MAJOR_VERSION <= 2:
        return typeguard.check_type(argname=argname, value=value, expected_type=expected_type) # type:ignore
    else:
        if isinstance(value, jsii._reference_map.InterfaceDynamicProxy): # pyright: ignore [reportAttributeAccessIssue]
           pass
        else:
            if TYPEGUARD_MAJOR_VERSION == 3:
                typeguard.config.collection_check_strategy = typeguard.CollectionCheckStrategy.ALL_ITEMS # type:ignore
                typeguard.check_type(value=value, expected_type=expected_type) # type:ignore
            else:
                typeguard.check_type(value=value, expected_type=expected_type, collection_check_strategy=typeguard.CollectionCheckStrategy.ALL_ITEMS) # type:ignore

from ._jsii import *

import aws_cdk as _aws_cdk_ceddda9d
import constructs as _constructs_77d1e7e8


class CfnSnapshot(
    _aws_cdk_ceddda9d.CfnResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdk-cloudformation/netapp-fsxn-snapshot.CfnSnapshot",
):
    '''A CloudFormation ``NetApp::FSxN::Snapshot``.

    :cloudformationResource: NetApp::FSxN::Snapshot
    :link: https://github.com/NetApp/NetApp-CloudFormation-FSx-ONTAP-provider
    '''

    def __init__(
        self,
        scope: _constructs_77d1e7e8.Construct,
        id: builtins.str,
        *,
        file_system_id: builtins.str,
        fsx_admin_password_source: typing.Union["PasswordSource", typing.Dict[builtins.str, typing.Any]],
        link_arn: builtins.str,
        name: builtins.str,
        svm: typing.Union["NameWithUuidRef", typing.Dict[builtins.str, typing.Any]],
        volume: typing.Union["NameWithUuidRef", typing.Dict[builtins.str, typing.Any]],
        comment: typing.Optional[builtins.str] = None,
        expiry_time: typing.Optional[builtins.str] = None,
        snaplock_expiry_time: typing.Optional[builtins.str] = None,
        snapmirror_label: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Create a new ``NetApp::FSxN::Snapshot``.

        :param scope: - scope in which this resource is defined.
        :param id: - scoped id of the resource.
        :param file_system_id: The file system ID of the Amazon FSx for NetApp ONTAP file system in which the resource is created.
        :param fsx_admin_password_source: The password source for the FSx admin user.
        :param link_arn: The ARN of the AWS Lambda function that will be invoked to manage the resource.
        :param name: The name of the snapshot copy to be created.
        :param svm: The reference to the SVM associated with the snapshot.
        :param volume: The reference to the volume associated with the snapshot.
        :param comment: Comment associated with the snapshot copy.
        :param expiry_time: The expiry time for the snapshot copy, matching the date time format: YYYY-MM-DD hh:mm:ss (UTC).
        :param snaplock_expiry_time: SnapLock expiry time for the snapshot copy, if the snapshot copy is taken on a SnapLock volume. A snapshot copy is not allowed to be deleted or renamed until the SnapLock ComplianceClock time goes beyond this retention time. Will be matching date time format: YYYY-MM-DD hh:mm:ss (UTC).
        :param snapmirror_label: Label for SnapMirror operations.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__fb20f00867f5c467efdd53ca03594587d564ab71807bc9b6ff701c51da5669e0)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = CfnSnapshotProps(
            file_system_id=file_system_id,
            fsx_admin_password_source=fsx_admin_password_source,
            link_arn=link_arn,
            name=name,
            svm=svm,
            volume=volume,
            comment=comment,
            expiry_time=expiry_time,
            snaplock_expiry_time=snaplock_expiry_time,
            snapmirror_label=snapmirror_label,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
        '''The CloudFormation resource type name for this resource class.'''
        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))

    @builtins.property
    @jsii.member(jsii_name="attrUuid")
    def attr_uuid(self) -> builtins.str:
        '''Attribute ``NetApp::FSxN::Snapshot.UUID``.

        :link: https://github.com/NetApp/NetApp-CloudFormation-FSx-ONTAP-provider
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrUuid"))

    @builtins.property
    @jsii.member(jsii_name="props")
    def props(self) -> "CfnSnapshotProps":
        '''Resource props.'''
        return typing.cast("CfnSnapshotProps", jsii.get(self, "props"))


@jsii.data_type(
    jsii_type="@cdk-cloudformation/netapp-fsxn-snapshot.CfnSnapshotProps",
    jsii_struct_bases=[],
    name_mapping={
        "file_system_id": "fileSystemId",
        "fsx_admin_password_source": "fsxAdminPasswordSource",
        "link_arn": "linkArn",
        "name": "name",
        "svm": "svm",
        "volume": "volume",
        "comment": "comment",
        "expiry_time": "expiryTime",
        "snaplock_expiry_time": "snaplockExpiryTime",
        "snapmirror_label": "snapmirrorLabel",
    },
)
class CfnSnapshotProps:
    def __init__(
        self,
        *,
        file_system_id: builtins.str,
        fsx_admin_password_source: typing.Union["PasswordSource", typing.Dict[builtins.str, typing.Any]],
        link_arn: builtins.str,
        name: builtins.str,
        svm: typing.Union["NameWithUuidRef", typing.Dict[builtins.str, typing.Any]],
        volume: typing.Union["NameWithUuidRef", typing.Dict[builtins.str, typing.Any]],
        comment: typing.Optional[builtins.str] = None,
        expiry_time: typing.Optional[builtins.str] = None,
        snaplock_expiry_time: typing.Optional[builtins.str] = None,
        snapmirror_label: typing.Optional[builtins.str] = None,
    ) -> None:
        '''A snapshot creates a read-only copy of a volume or LUN at a specific time.

        It allows users to restore files or volumes if data is deleted, corrupted, or changed. Snapshots efficiently store only the changes made after the snapshot, making them ideal for data protection and recovery. Once activated, you need a preview key to consume this resource. Please reach out to Ng-fsx-cloudformation@netapp.com to get the key. To use this resource, you must first create the Link module.

        :param file_system_id: The file system ID of the Amazon FSx for NetApp ONTAP file system in which the resource is created.
        :param fsx_admin_password_source: The password source for the FSx admin user.
        :param link_arn: The ARN of the AWS Lambda function that will be invoked to manage the resource.
        :param name: The name of the snapshot copy to be created.
        :param svm: The reference to the SVM associated with the snapshot.
        :param volume: The reference to the volume associated with the snapshot.
        :param comment: Comment associated with the snapshot copy.
        :param expiry_time: The expiry time for the snapshot copy, matching the date time format: YYYY-MM-DD hh:mm:ss (UTC).
        :param snaplock_expiry_time: SnapLock expiry time for the snapshot copy, if the snapshot copy is taken on a SnapLock volume. A snapshot copy is not allowed to be deleted or renamed until the SnapLock ComplianceClock time goes beyond this retention time. Will be matching date time format: YYYY-MM-DD hh:mm:ss (UTC).
        :param snapmirror_label: Label for SnapMirror operations.

        :schema: CfnSnapshotProps
        '''
        if isinstance(fsx_admin_password_source, dict):
            fsx_admin_password_source = PasswordSource(**fsx_admin_password_source)
        if isinstance(svm, dict):
            svm = NameWithUuidRef(**svm)
        if isinstance(volume, dict):
            volume = NameWithUuidRef(**volume)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__5b28a57870197723758e5782603baf240bdd7c6d85d2d9e024e62f0795993cb0)
            check_type(argname="argument file_system_id", value=file_system_id, expected_type=type_hints["file_system_id"])
            check_type(argname="argument fsx_admin_password_source", value=fsx_admin_password_source, expected_type=type_hints["fsx_admin_password_source"])
            check_type(argname="argument link_arn", value=link_arn, expected_type=type_hints["link_arn"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument svm", value=svm, expected_type=type_hints["svm"])
            check_type(argname="argument volume", value=volume, expected_type=type_hints["volume"])
            check_type(argname="argument comment", value=comment, expected_type=type_hints["comment"])
            check_type(argname="argument expiry_time", value=expiry_time, expected_type=type_hints["expiry_time"])
            check_type(argname="argument snaplock_expiry_time", value=snaplock_expiry_time, expected_type=type_hints["snaplock_expiry_time"])
            check_type(argname="argument snapmirror_label", value=snapmirror_label, expected_type=type_hints["snapmirror_label"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "file_system_id": file_system_id,
            "fsx_admin_password_source": fsx_admin_password_source,
            "link_arn": link_arn,
            "name": name,
            "svm": svm,
            "volume": volume,
        }
        if comment is not None:
            self._values["comment"] = comment
        if expiry_time is not None:
            self._values["expiry_time"] = expiry_time
        if snaplock_expiry_time is not None:
            self._values["snaplock_expiry_time"] = snaplock_expiry_time
        if snapmirror_label is not None:
            self._values["snapmirror_label"] = snapmirror_label

    @builtins.property
    def file_system_id(self) -> builtins.str:
        '''The file system ID of the Amazon FSx for NetApp ONTAP file system in which the resource is created.

        :schema: CfnSnapshotProps#FileSystemId
        '''
        result = self._values.get("file_system_id")
        assert result is not None, "Required property 'file_system_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def fsx_admin_password_source(self) -> "PasswordSource":
        '''The password source for the FSx admin user.

        :schema: CfnSnapshotProps#FsxAdminPasswordSource
        '''
        result = self._values.get("fsx_admin_password_source")
        assert result is not None, "Required property 'fsx_admin_password_source' is missing"
        return typing.cast("PasswordSource", result)

    @builtins.property
    def link_arn(self) -> builtins.str:
        '''The ARN of the AWS Lambda function that will be invoked to manage the resource.

        :schema: CfnSnapshotProps#LinkArn
        '''
        result = self._values.get("link_arn")
        assert result is not None, "Required property 'link_arn' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of the snapshot copy to be created.

        :schema: CfnSnapshotProps#Name
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def svm(self) -> "NameWithUuidRef":
        '''The reference to the SVM associated with the snapshot.

        :schema: CfnSnapshotProps#SVM
        '''
        result = self._values.get("svm")
        assert result is not None, "Required property 'svm' is missing"
        return typing.cast("NameWithUuidRef", result)

    @builtins.property
    def volume(self) -> "NameWithUuidRef":
        '''The reference to the volume associated with the snapshot.

        :schema: CfnSnapshotProps#Volume
        '''
        result = self._values.get("volume")
        assert result is not None, "Required property 'volume' is missing"
        return typing.cast("NameWithUuidRef", result)

    @builtins.property
    def comment(self) -> typing.Optional[builtins.str]:
        '''Comment associated with the snapshot copy.

        :schema: CfnSnapshotProps#Comment
        '''
        result = self._values.get("comment")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def expiry_time(self) -> typing.Optional[builtins.str]:
        '''The expiry time for the snapshot copy, matching the date time format: YYYY-MM-DD hh:mm:ss (UTC).

        :schema: CfnSnapshotProps#ExpiryTime
        '''
        result = self._values.get("expiry_time")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def snaplock_expiry_time(self) -> typing.Optional[builtins.str]:
        '''SnapLock expiry time for the snapshot copy, if the snapshot copy is taken on a SnapLock volume.

        A snapshot copy is not allowed to be deleted or renamed until the SnapLock ComplianceClock time goes beyond this retention time. Will be matching date time format: YYYY-MM-DD hh:mm:ss (UTC).

        :schema: CfnSnapshotProps#SnaplockExpiryTime
        '''
        result = self._values.get("snaplock_expiry_time")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def snapmirror_label(self) -> typing.Optional[builtins.str]:
        '''Label for SnapMirror operations.

        :schema: CfnSnapshotProps#SnapmirrorLabel
        '''
        result = self._values.get("snapmirror_label")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CfnSnapshotProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdk-cloudformation/netapp-fsxn-snapshot.NameWithUuidRef",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "uuid": "uuid"},
)
class NameWithUuidRef:
    def __init__(
        self,
        *,
        name: typing.Optional[builtins.str] = None,
        uuid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: The name part of the reference, which can be used to identify resources such as SVM or volume.
        :param uuid: The UUID part of the reference, which can be used to identify resources such as SVM or volume.

        :schema: NameWithUuidRef
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__7f3d19e38dbeda3641f95a43888dad685598a4ba2eec5c07e9566447a1b2f556)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument uuid", value=uuid, expected_type=type_hints["uuid"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if name is not None:
            self._values["name"] = name
        if uuid is not None:
            self._values["uuid"] = uuid

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''The name part of the reference, which can be used to identify resources such as SVM or volume.

        :schema: NameWithUuidRef#Name
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def uuid(self) -> typing.Optional[builtins.str]:
        '''The UUID part of the reference, which can be used to identify resources such as SVM or volume.

        :schema: NameWithUuidRef#UUID
        '''
        result = self._values.get("uuid")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NameWithUuidRef(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdk-cloudformation/netapp-fsxn-snapshot.PasswordSource",
    jsii_struct_bases=[],
    name_mapping={"secret": "secret"},
)
class PasswordSource:
    def __init__(
        self,
        *,
        secret: typing.Union["SecretSource", typing.Dict[builtins.str, typing.Any]],
    ) -> None:
        '''
        :param secret: A reference to the source of the password, typically an AWS Secrets Manager secret.

        :schema: PasswordSource
        '''
        if isinstance(secret, dict):
            secret = SecretSource(**secret)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__48054ece50afbc4bd0f6de503b05fe6dc37b9ce8d3a7027cfa6a2c7e17d38553)
            check_type(argname="argument secret", value=secret, expected_type=type_hints["secret"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "secret": secret,
        }

    @builtins.property
    def secret(self) -> "SecretSource":
        '''A reference to the source of the password, typically an AWS Secrets Manager secret.

        :schema: PasswordSource#Secret
        '''
        result = self._values.get("secret")
        assert result is not None, "Required property 'secret' is missing"
        return typing.cast("SecretSource", result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PasswordSource(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdk-cloudformation/netapp-fsxn-snapshot.SecretSource",
    jsii_struct_bases=[],
    name_mapping={"secret_arn": "secretArn", "secret_key": "secretKey"},
)
class SecretSource:
    def __init__(self, *, secret_arn: builtins.str, secret_key: builtins.str) -> None:
        '''
        :param secret_arn: The ARN of the secret stored in AWS Secrets Manager.
        :param secret_key: Reference for the SecretKey. The actual password is stored in AWS Secret Manager.

        :schema: SecretSource
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__06abdfcad0ad0bb984d246e99d9f603c15e4e44ddf7928616903e70b675c7451)
            check_type(argname="argument secret_arn", value=secret_arn, expected_type=type_hints["secret_arn"])
            check_type(argname="argument secret_key", value=secret_key, expected_type=type_hints["secret_key"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "secret_arn": secret_arn,
            "secret_key": secret_key,
        }

    @builtins.property
    def secret_arn(self) -> builtins.str:
        '''The ARN of the secret stored in AWS Secrets Manager.

        :schema: SecretSource#SecretArn
        '''
        result = self._values.get("secret_arn")
        assert result is not None, "Required property 'secret_arn' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def secret_key(self) -> builtins.str:
        '''Reference for the SecretKey.

        The actual password is stored in AWS Secret Manager.

        :schema: SecretSource#SecretKey
        '''
        result = self._values.get("secret_key")
        assert result is not None, "Required property 'secret_key' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SecretSource(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


__all__ = [
    "CfnSnapshot",
    "CfnSnapshotProps",
    "NameWithUuidRef",
    "PasswordSource",
    "SecretSource",
]

publication.publish()

def _typecheckingstub__fb20f00867f5c467efdd53ca03594587d564ab71807bc9b6ff701c51da5669e0(
    scope: _constructs_77d1e7e8.Construct,
    id: builtins.str,
    *,
    file_system_id: builtins.str,
    fsx_admin_password_source: typing.Union[PasswordSource, typing.Dict[builtins.str, typing.Any]],
    link_arn: builtins.str,
    name: builtins.str,
    svm: typing.Union[NameWithUuidRef, typing.Dict[builtins.str, typing.Any]],
    volume: typing.Union[NameWithUuidRef, typing.Dict[builtins.str, typing.Any]],
    comment: typing.Optional[builtins.str] = None,
    expiry_time: typing.Optional[builtins.str] = None,
    snaplock_expiry_time: typing.Optional[builtins.str] = None,
    snapmirror_label: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__5b28a57870197723758e5782603baf240bdd7c6d85d2d9e024e62f0795993cb0(
    *,
    file_system_id: builtins.str,
    fsx_admin_password_source: typing.Union[PasswordSource, typing.Dict[builtins.str, typing.Any]],
    link_arn: builtins.str,
    name: builtins.str,
    svm: typing.Union[NameWithUuidRef, typing.Dict[builtins.str, typing.Any]],
    volume: typing.Union[NameWithUuidRef, typing.Dict[builtins.str, typing.Any]],
    comment: typing.Optional[builtins.str] = None,
    expiry_time: typing.Optional[builtins.str] = None,
    snaplock_expiry_time: typing.Optional[builtins.str] = None,
    snapmirror_label: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__7f3d19e38dbeda3641f95a43888dad685598a4ba2eec5c07e9566447a1b2f556(
    *,
    name: typing.Optional[builtins.str] = None,
    uuid: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__48054ece50afbc4bd0f6de503b05fe6dc37b9ce8d3a7027cfa6a2c7e17d38553(
    *,
    secret: typing.Union[SecretSource, typing.Dict[builtins.str, typing.Any]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__06abdfcad0ad0bb984d246e99d9f603c15e4e44ddf7928616903e70b675c7451(
    *,
    secret_arn: builtins.str,
    secret_key: builtins.str,
) -> None:
    """Type checking stubs"""
    pass
